@@ -3,7 +3,7 @@ import sys
 import codecs
 import json
 
-from pymongo import json_util
+from bson import json_util
 
 def json_load(filename):
     if filename == "-":
